@@ -1,7 +1,7 @@
 #' @include query-classes.R
 #' @include management-api-classes.R
 #' @include view-coerce.R
-#' @include Query-generics.R
+#' @include GaView-generics.R
 #' @importFrom methods setMethod as as<- callNextMethod
 NULL
 
@@ -25,7 +25,13 @@ setMethod(
   }
 )
 
-#' @describeIn GaView Select the default view of the property
+#' @describeIn GaView Select the default view of the property.
+#' @examples
+#' \dontrun{
+#'    my_ga_account <- GaAccounts()[['60253332']]
+#'    my_website_property <- my_ga_account$properties[['UA-60253332-2']]
+#'    my_default_view <- GaView(my_website_property)
+#' }
 setMethod(
   "GaView",
   signature = c("gaProperty", "missing"),
@@ -38,8 +44,13 @@ setMethod(
   }
 )
 
-#' @describeIn GaView Selects the first property of the account, which is then
-#' used to select a view (as above).
+#' @describeIn GaView Select the default view of the first listed property of
+#'   the account.
+#' @examples
+#' \dontrun{
+#'    my_ga_account <- GaAccounts()[['60253332']]
+#'    my_default_view <- GaView(my_ga_account)
+#' }
 setMethod(
   "GaView",
   signature = c("gaAccount", "missing"),
@@ -48,29 +59,38 @@ setMethod(
   }
 )
 
-# -- GaView ----
-#' @describeIn GaView Returns the ID of the supplied view, or the first view
-#'   within the supplied property or the first view within the first property of
-#'   the supplied account, or coerce a numeric or character into a viewId.
-setMethod("GaView", c("ANY", "missing"),
-          function(object) {
-            as(object, "viewId")
-          }
-        )
-
-#' @describeIn GaView gets the view ID of the supplied query
-setMethod("GaView", c(".query", "missing"),
-          function(object) {
-            object@viewId
-          }
+#' @describeIn GaView Returns the ID of the supplied view, or the default view
+#'   within the supplied property or the default view within the first property
+#'   of the supplied account, or coerces a numeric or character into a
+#'   \code{viewId}.
+setMethod(
+  "GaView",
+  signature = c("ANY", "missing"),
+  definition = function(object) {
+    as(object, "viewId")
+  }
 )
 
-#' @describeIn GaView Set the view of a query, returning the query with the updated view applied.
-setMethod("GaView", c(".query", "ANY"),
-          function(object, value) {
-            as(object, "viewId") <- value
-          }
-        )
+#' @describeIn GaView gets the view ID of the supplied query.
+setMethod(
+  "GaView",
+  signature = c(".query", "missing"),
+  definition = function(object) {
+    object@viewId
+  }
+)
+
+#' @describeIn GaView Set the view of a query, returning the query with the
+#'   updated view applied.
+setMethod(
+  "GaView",
+  signature = c(".query", "ANY"),
+  definition = function(object, value) {
+    as(object, "viewId") <- value
+    validObject(object)
+    object
+  }
+)
 
 #' @describeIn GaView Replaces the view being used by a query.
 setMethod(
